<?php
namespace Example\RedirectTest\Utility;

use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Core\Mail\MailMessage;

/*
 * This file is part of the TYPO3 CMS project.
 *
 * It is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, either version 2
 * of the License, or any later version.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 *
 * The TYPO3 project - inspiring people to share!
 */

class MailerUtility
{
    /**
     * $data = [
     *     'subject' => 'Email subject',
     *     'sender' => 'Email of the sender',
     *     'senderName' => 'Name of the sender',
     *     'receivers' => [
     *
     *     ]
     * ];
     *
     * @param array $data
     * @return bool
     */
    public static function send(array $data): bool
    {
        /** @var MailMessage $mail */
        $mail = GeneralUtility::makeInstance(MailMessage::class);

        if (isset($data['subject'])) {
            $mail->setSubject($data['subject']);
        }

        if (isset($data['sender'])) {
            $mail->setFrom($data['sender'], $data['senderName']);
        }

        if (isset($data['receivers'])) {
            $mail->setTo($data['receivers']);
        }

        if (isset($data['bccReceivers']) &&
            is_array($data['bccReceivers']) &&
            !empty($data['bccReceivers'])
        ) {
            $mail->setBcc($data['bccReceivers']);
        }

        if (isset($data['html'])) {
            $mail->setBody($data['html'], 'text/html');
        }

        if (isset($data['plain'])) {
            $mail->setBody($data['plain'], 'text/plain');
        }

        if (isset($data['plain_additional'])) {
            $mail->addPart($data['plain'], 'text/plain');
        }

        $mail->send();

        return $mail->isSent();
    }
}
